Crate dtg_credentials

Crate dtg_credentials 

Decentralized Trust Graph (DTG) Credentials

Modules

authority
Verifying a chain of Verifiable Authority Credentials.
create
Builder methods for creating new entities.
delegation
Verifying a chain of Verifiable Delegation Credentials.

Structs

AuthorityGrant
The authority object a CredentialSubject::Authority carries.
CredentialSubjectAuthority
Verifiable Authority Credential (VAC) subject.
CredentialSubjectBasic
id of the credential subject only
CredentialSubjectDelegation
Delegation Credential subject
CredentialSubjectEndorsement
Endorsement Credential subject
CredentialSubjectMembership
Membership Credential subject
CredentialSubjectRCardDeprecated
R-Card Credential subject
CredentialSubjectWitness
Witness Credential subject
DTGCommon
All DTG Credentials follow a common structure.
DTGCredential
Defined DTG Credentials
DelegationGrant
The delegation object a CredentialSubject::Delegation carries.
WitnessContext
Witness Credential Context

Enums

CredentialSubject
This represents all possible credential subjects The order of the enum is important as it will match on first match
DTGCredentialError
Errors related to DTG Credentials
DTGCredentialType
TDG VC Type Identifiers
W3CVCVersion
What W3C VC Format is the credential using?

Functions

decode_digest_multibase
Decodes a digestMultibase value into the algorithm it names and the raw digest bytes.
digest_jsonDeprecated
A credential’s digest in the superseded sha256:<hex> encoding.
digest_multibase_json
The digest a DTG credential carries of another credential, computed over that credential in its wire form.
digests_match
Do two digestMultibase values refer to the same credential?